#ifndef NT2_INCLUDE_CONSTANTS_REAL_SPLAT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_REAL_SPLAT_HPP_INCLUDED

#include <nt2/constant/include/constants/real_splat.hpp>

#endif
